@@ -9,8 +9,8 @@
  *     Olof Sivertsson <olsi0767@student.uu.se>
  *
  *  Last modified:
- *     $Date: 2006-06-20 02:25:09 +0200 (Tue, 20 Jun 2006) $ by $Author: schulte $
- *     $Revision: 3307 $
+ *     $Date: 2006-08-31 17:36:38 +0200 (Thu, 31 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3579 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -91,7 +91,7 @@ public:
 	row1[j] = p(i-1,j);
 	row2[j] = p(i,j);
       }
-      lex(this, row1, IRT_GQ, row2);
+      rel(this, row1, IRT_GQ, row2);
     }
     for (int j=1;j<par.b;j++) {
       BoolVarArgs col1(par.v);
@@ -100,10 +100,10 @@ public:
 	col1[i] = p(i,j-1);
 	col2[i] = p(i,j);
       }
-      lex(this, col1, IRT_GQ, col2);
+      rel(this, col1, IRT_GQ, col2);
     }
 
-    branch(this, _p, BVAR_NONE, 
+    branch(this, _p, BVAR_NONE,
 	   (opt.naive ? BVAL_MIN : BVAL_MAX));
   }
 
@@ -164,7 +164,7 @@ main(int argc, char** argv) {
     std::cerr << "Error: size must be between 0 and 9" << std::endl;
     return 1;
   }
-  
+
   Example::run<BIBD,DFS>(opt);
   return 0;
 }
