@@ -6,8 +6,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2005-12-08 13:15:17 +0100 (Thu, 08 Dec 2005) $ by $Author: tack $
- *     $Revision: 2743 $
+ *     $Date: 2006-08-04 16:06:52 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3517 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -21,12 +21,12 @@
 
 #include "examples/support.hh"
 
-/** 
+/**
  * \name Graph specification for graph coloring
  *
- * The edges are described by an array of integers with even number 
+ * The edges are described by an array of integers with even number
  * of elements, terminated by the elements -1,-1.
- * The cliques are described by an array of integers, where the first 
+ * The cliques are described by an array of integers, where the first
  * integer gives the size of the clique, the following elements are
  * nodes for each clique. The cliques are terminated by -1 for clique size
  *
@@ -39,6 +39,8 @@ public:
   const int  n_v; ///< Number of nodes
   const int* e;   ///< Edges
   const int* c;   ///< Cliques
+  GraphColorSpec(const int n_v0, const int* e0, const int* c0)
+    : n_v(n_v0), e(e0), c(c0) {}
 };
 
 /// First example graph: edges
@@ -165,10 +167,7 @@ static const int g1_c[] = {
   -1};
 
 /// First example graph
-static const GraphColorSpec g1 = {
-  200, g1_e, g1_c
-};
-
+static const GraphColorSpec g1(200, g1_e, g1_c);
 
 /// Second example graph: edges
 static const int g2_e[] = {
@@ -281,9 +280,7 @@ static const int g2_c[] = {
   -1};
 
 /// Second example graph
-static const GraphColorSpec g2 = {
-  200, g2_e, g2_c
-};
+static const GraphColorSpec g2(200, g2_e, g2_c);
 //@}
 
 /**
@@ -302,8 +299,8 @@ private:
 public:
   /// The actual model
   GraphColor(const Options& opt)
-    : g(opt.size == 1 ? g2 : g1), 
-      v(this,g.n_v,0,g.n_v), 
+    : g(opt.size == 1 ? g2 : g1),
+      v(this,g.n_v,0,g.n_v),
       m(this,0,g.n_v) {
     for (int i = g.n_v; i--; )
       rel(this, v[i], IRT_LQ, m);
@@ -314,10 +311,13 @@ public:
     for (int i = *c++; i--; c++)
       rel(this, v[*c], IRT_EQ, i);
     while (*c != -1) {
-      IntVarArgs x(*c); c++;
-      for (int i = x.size(); i--; c++)
+      int n = *c;
+      IntVarArgs x(n); c++;
+      for (int i = n; i--; c++)
 	x[i] = v[*c];
       distinct(this, x, opt.icl);
+      if (!opt.naive)
+	rel(this, m, IRT_GQ, n);
     }
     IntVarArgs ma(1);
     ma[0] = m;
@@ -361,8 +361,7 @@ main(int argc, char** argv) {
   Options opt("GraphColor");
   opt.naive      = false;
   opt.icl        = ICL_DOM;
-  opt.iterations = 5;
-  opt.c_d        = 10;
+  opt.iterations = 20;
   opt.parse(argc,argv);
   Example::run<GraphColor,DFS>(opt);
   return 0;
