@@ -6,8 +6,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2006-04-11 15:58:37 +0200 (Tue, 11 Apr 2006) $ by $Author: tack $
- *     $Revision: 3188 $
+ *     $Date: 2006-08-04 16:06:52 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3517 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -22,7 +22,7 @@
 #include "examples/support.hh"
 #include "gecode/minimodel.hh"
 
-/** 
+/**
  * \name Graph specification for independent sets
  *
  * \relates IndSet
@@ -34,6 +34,8 @@ public:
   const int  n_v; ///< Number of vertices
   const int  n_e; ///< Number of edges
   const int* e;   ///< Arrays of edges (as vertex pairs)
+  Graph(const int n_v0, const int n_e0, const int* e0)
+    : n_v(n_v0), n_e(n_e0), e(e0) {}
 };
 
 static const int e_20_10[] = {
@@ -41,7 +43,7 @@ static const int e_20_10[] = {
   9,12,  5,11,   6,15,   3,18,   7,16
 };
 
-static const Graph g_20_10 = { 20, 10, e_20_10 };
+static const Graph g_20_10(20,10,e_20_10);
 
 static const int e_40_20[] = {
   21,30,   11,30,   19,38,   20,25,   11,24,
@@ -50,7 +52,7 @@ static const int e_40_20[] = {
   19,25,   11,22,   13,30,    7,36,   15,33
 };
 
-static const Graph g_40_20 = { 40, 20, e_40_20 };
+static const Graph g_40_20(40, 20, e_40_20);
 //@}
 
 
@@ -76,7 +78,7 @@ public:
     const int* e = g.e;
     const int* e1 = e++; const int* e2 = e++;
     for (int i = g.n_e; i--; )
-      post(this, v[*e1]+v[*e2] <= 1);
+      bool_and(this, v[*e1],v[*e2],false);
     linear(this, v, IRT_EQ, k);
     branch(this, v, BVAR_NONE, BVAL_MIN);
   }
@@ -118,7 +120,7 @@ main(int argc, char** argv) {
   Options opt("IndSet");
   opt.solutions  = 0;
   opt.size       = 1;
-  opt.iterations = 1000;
+  opt.iterations = 2000;
   opt.parse(argc,argv);
   Example::run<IndSet,BAB>(opt);
   return 0;
