@@ -6,8 +6,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2006-04-11 15:58:37 +0200 (Tue, 11 Apr 2006) $ by $Author: tack $
- *     $Revision: 3188 $
+ *     $Date: 2006-08-04 16:06:52 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3517 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -58,7 +58,7 @@ public:
       IntVar p(this,0,nn-1);
       IntVar s(this,0,nn-1);
       pred[i]=p; succ[i]=s;
-    } 
+    }
 
     // Place the first two knights
     rel(this, jump[field(0,0)], IRT_EQ, 0);
@@ -90,7 +90,7 @@ public:
 	  rel(this, succ[f], IRT_EQ, g, b);
 	  rel(this, pred[g], IRT_EQ, f, b);
 
-	  bool_xor(this, 
+	  bool_xor(this,
 		   post(this, ~(jump[g]-jump[f] == 1)),
 		   post(this, ~(jump[g]-jump[f] == 1-nn)),
 		   b);
@@ -135,10 +135,8 @@ public:
 int
 main(int argc, char** argv) {
   Options opt("Knights");
-  opt.iterations = 50;
+  opt.iterations = 100;
   opt.size       = 8;
-  opt.c_d        = 25;
-  opt.a_d        = 5;
   opt.parse(argc,argv);
   Example::run<Knights,DFS>(opt);
   return 0;
