@@ -6,8 +6,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2006-04-11 15:58:37 +0200 (Tue, 11 Apr 2006) $ by $Author: tack $
- *     $Revision: 3188 $
+ *     $Date: 2006-08-04 16:06:52 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3517 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -28,6 +28,8 @@ public:
   const int  n_names; ///< Number of people on picture
   const int  n_prefs; ///< Number of preferences
   const int* prefs;   ///< Array of preferences
+  PhotoSpec(const int n_n, const int n_p, const int* p)
+    : n_names(n_n), n_prefs(n_p), prefs(p) {}
 };
 
 /// Preferences for small example
@@ -35,7 +37,7 @@ static const int s_prefs[] = {
   0,2, 1,4, 2,3, 2,4, 3,0, 4,3, 4,0, 4,1
 };
 /// Small Photo example
-static const PhotoSpec p_small = { 5, 8, s_prefs};
+static const PhotoSpec p_small(5, 8, s_prefs);
 
 /// Preferences for large example
 static const int l_prefs[] = {
@@ -43,7 +45,7 @@ static const int l_prefs[] = {
   4,5, 4,0, 5,0, 5,8, 6,2, 6,7, 7,8, 7,6
 };
 /// Large Photo example
-static const PhotoSpec p_large = { 9,17, l_prefs };
+static const PhotoSpec p_large(9,17, l_prefs);
 
 /**
  * \brief %Example: Placing people on a photo
@@ -95,7 +97,7 @@ public:
 
     // Break some symmetries
     rel(this, pos[0], IRT_LE, pos[1]);
-    
+
     if (opt.naive) {
       branch(this, pos, BVAR_NONE, BVAL_MIN);
     } else {
