@@ -6,8 +6,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2006-06-14 15:31:47 +0200 (Wed, 14 Jun 2006) $ by $Author: tack $
- *     $Revision: 3294 $
+ *     $Date: 2006-08-16 13:07:15 +0200 (Wed, 16 Aug 2006) $ by $Author: zayenz $
+ *     $Revision: 3541 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -32,7 +32,7 @@ static const char* icl2str[] =
 static const char* em2str[] =
   { "solution", "time", "stat" };
 
-static const char* bool2str[] = 
+static const char* bool2str[] =
   { "false", "true" };
 
 void
@@ -42,9 +42,9 @@ Options::parse(int argc, char** argv) {
   const char* e = NULL;
   while (i < argc) {
     if (!strcmp(argv[i],"-help") || !strcmp(argv[i],"--help")) {
-      cerr << "Options for example " << name << ":" 
+      cerr << "Options for example " << name << ":"
 	   << endl
-	   << "\t-icl (def,val,bnd,dom) default: " << icl2str[icl] 
+	   << "\t-icl (def,val,bnd,dom) default: " << icl2str[icl]
 	   << endl
 	   << "\t\tinteger consistency level" << endl
 	   << "\t-c_d (unsigned int) default: " << c_d << endl
@@ -55,10 +55,10 @@ Options::parse(int argc, char** argv) {
 	   << em2str[mode] << endl
 	   << "\t\twhether to print solutions, measure time, "
 	   << "or print statistics" << endl
-	   << "\t-samples (unsigned int) default: " 
+	   << "\t-samples (unsigned int) default: "
 	   << samples << endl
 	   << "\t\thow many samples (time-mode)" << endl
-	   << "\t-iterations (unsigned int) default: " 
+	   << "\t-iterations (unsigned int) default: "
 	   << iterations << endl
 	   << "\t\thow many iterations per sample (time-mode)" << endl
 	   << "\t-solutions (unsigned int) default: ";
@@ -68,7 +68,14 @@ Options::parse(int argc, char** argv) {
 	cerr << solutions;
       cerr << endl
 	   << "\t\thow many solutions to search (solution-mode)" << endl
-	   << "\t-naive default: " 
+	   << "\t-fails (unsigned int) default: "
+	   << (fails<0 ? "(no limit) " : "") << fails << endl
+	   << "\t\tset number of allowed fails before stopping (solution-mode)"
+	   << endl
+	   << "\t-time (unsigned int) default: "
+	   << (fails<0 ? "(no limit) " : "") << time << endl
+	   << "\t\tset allowed time before stopping (solution-mode)" << endl
+	   << "\t-naive default: "
 	   << bool2str[naive] << endl
 	   << "\t\tuse naive version" << endl
 	   << "\t-smart default: "
@@ -117,6 +124,12 @@ Options::parse(int argc, char** argv) {
     } else if (!strcmp(argv[i],"-solutions")) {
       if (++i == argc) goto missing;
       solutions = atoi(argv[i]);
+    } else if (!strcmp(argv[i],"-fails")) {
+      if (++i == argc) goto missing;
+      fails = atoi(argv[i]);
+    } else if (!strcmp(argv[i],"-time")) {
+      if (++i == argc) goto missing;
+      time = atoi(argv[i]);
     } else if (!strcmp(argv[i],"-iterations")) {
       if (++i == argc) goto missing;
       iterations = atoi(argv[i]);
@@ -138,8 +151,8 @@ Options::parse(int argc, char** argv) {
  missing:
   e = "missing argument";
  error:
-  cerr << "Erroneous argument (" << argv[i-1] << ")" << endl
-       << e << endl;
+  cerr << "Erroneous argument (" << argv[i-1] << ")" << endl;
+  if (e) cerr << e << endl;
   exit(EXIT_FAILURE);
 }
 
