@@ -6,8 +6,8 @@
  *     Christian Schulte, 2006
  *
  *  Last modified:
- *     $Date: 2005-10-27 21:01:30 +0200 (Thu, 27 Oct 2005) $ by $Author: schulte $
- *     $Revision: 2420 $
+ *     $Date: 2006-08-04 16:03:26 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3512 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,20 +42,18 @@ namespace Gecode {
       ValInfo<IntView>* vi
 	= ValInfo<IntView>::allocate(home,2*n);
       for (int i=n; i--; ) {
-	vi[i  ].init(x[i],n); 
+	vi[i  ].init(x[i],n);
 	vi[i+n].init(y[i],n);
       }
-      if (Val<IntView>::post(home,n,vi) == ES_FAILED)
-	home->fail();
+      GECODE_ES_FAIL(home,Val<IntView>::post(home,n,vi));
     } else {
       DomInfo<IntView>* di
 	= DomInfo<IntView>::allocate(home,2*n);
       for (int i=n; i--; ) {
-	di[i  ].init(x[i],n); 
+	di[i  ].init(x[i],n);
 	di[i+n].init(y[i],n);
       }
-      if (Dom<IntView>::post(home,n,di) == ES_FAILED)
-	home->fail();
+      GECODE_ES_FAIL(home,Dom<IntView>::post(home,n,di));
     }
   }
 
