@@ -6,8 +6,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2006-05-17 16:00:08 +0200 (Wed, 17 May 2006) $ by $Author: schulte $
- *     $Revision: 3226 $
+ *     $Date: 2006-08-04 16:03:17 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3511 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -28,11 +28,10 @@ namespace Gecode { namespace Search {
    *
    */
 
-  DFS::DFS(Space* s, unsigned int c_d, unsigned int a_d, Stop* st, size_t sz) 
+  DFS::DFS(Space* s, unsigned int c_d, unsigned int a_d, Stop* st, size_t sz)
     : e(c_d,a_d,st,sz) {
-    unsigned int alt;
     unsigned long int p = 0;
-    Space* c = (s->status(alt,p) == SS_FAILED) ? NULL : s->clone();
+    Space* c = (s->status(p) == SS_FAILED) ? NULL : s->clone(true,p);
     e.init(c);
     e.propagate += p;
     e.current(s);
@@ -41,7 +40,7 @@ namespace Gecode { namespace Search {
     if (c == NULL)
       e.fail += 1;
   }
-  
+
   Space*
   DFS::next(void) {
     return e.explore();
