@@ -6,8 +6,8 @@
  *     Christian Schulte, 2006
  *
  *  Last modified:
- *     $Date: 2005-08-10 20:28:01 +0200 (Wed, 10 Aug 2005) $ by $Author: schulte $
- *     $Revision: 2202 $
+ *     $Date: 2006-08-04 16:03:17 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3511 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -23,13 +23,6 @@
 
 namespace Gecode { namespace Search {
 
-  /*
-   * Base class
-   *
-   */
-  Stop::~Stop(void) {}
-
-
   /*
    * Stopping for memory limit
    *
@@ -39,7 +32,7 @@ namespace Gecode { namespace Search {
     return s.memory > l;
   }
 
-  
+
   /*
    * Stopping for memory limit
    *
@@ -49,7 +42,7 @@ namespace Gecode { namespace Search {
     return s.fail > l;
   }
 
-  
+
   /*
    * Stopping for memory limit
    *
@@ -57,7 +50,7 @@ namespace Gecode { namespace Search {
   bool
   TimeStop::stop(const Statistics&) {
     return static_cast<unsigned long int>
-      ((static_cast<double>(clock()-s)/CLOCKS_PER_SEC) * 1000.0) > l; 
+      ((static_cast<double>(clock()-s)/CLOCKS_PER_SEC) * 1000.0) > l;
   }
 
 }}
