@@ -8,8 +8,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2006-04-03 13:09:53 +0200 (Mon, 03 Apr 2006) $ by $Author: schulte $
- *     $Revision: 3147 $
+ *     $Date: 2006-08-04 16:07:12 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3518 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -29,15 +29,15 @@ Assignment::Assignment(int n0, const IntSet& d0)
   : n(n0), dsv(new IntSetValues[n]), d(d0) {
   reset();
 }
- 
-void 
+
+void
 Assignment::reset(void) {
   done = false;
   for (int i=n; i--; )
     dsv[i].init(d);
 }
 
-void 
+void
 Assignment::operator++(void) {
   int i = n-1;
   while (true) {
@@ -59,25 +59,25 @@ RandomAssignment::RandomAssignment(int n0, const IntSet& d0, int count0)
   reset();
 }
 
-void 
+void
 RandomAssignment::reset(void) {
   left = count;
   for (int i=n; i--; )
     vals[i] = randval();
 }
 
-void 
+void
 RandomAssignment::operator++(void) {
-  for (int i = n; i--; ) 
+  for (int i = n; i--; )
     vals[i] = randval();
   --left;
 }
 
-int 
+int
 RandomAssignment::randval(void) {
   int v;
   IntSetRanges it(d);
-  unsigned int skip = random(d.size());
+  unsigned int skip = Test::randgen(d.size());
   while (true) {
     if (it.width() > skip) {
       v = it.min() + skip;
@@ -100,11 +100,11 @@ operator<<(std::ostream& os, const Assignment& a) {
 
 #define FORCE_FIXFLUSH				\
 do {						\
-  if (random(opt.fixprob) == 0) {		\
+  if (Test::randgen(opt.fixprob) == 0) {	\
     Log::fixpoint();				\
     if (status() == SS_FAILED) return;	        \
   }						\
-  if (random(opt.flushprob) == 0) {		\
+  if (Test::randgen(opt.flushprob) == 0) {	\
     flush();					\
     Log::flush();				\
   }						\
@@ -117,7 +117,7 @@ private:
   const Options opt;
 
 public:
-  IntTestSpace(int n, IntSet& d, const Options& o) 
+  IntTestSpace(int n, IntSet& d, const Options& o)
     : x(this, n, d), opt(o) {
     Log::initial(x, "x");
   }
@@ -146,15 +146,15 @@ public:
   }
   void prune(void) {
     // Select variable to be pruned
-    int i = random(x.size());
+    int i = Test::randgen(x.size());
     while (x[i].assigned()) {
       i = (i+1) % x.size();
     }
     // Prune values
-    for (int vals = random(x[i].size()-1)+1; vals--; ) {
+    for (int vals = Test::randgen(x[i].size()-1)+1; vals--; ) {
       int v;
       Int::ViewRanges<Int::IntView> it(x[i]);
-      unsigned int skip = random(x[i].size()-1);
+      unsigned int skip = Test::randgen(x[i].size()-1);
       while (true) {
 	if (it.width() > skip) {
 	  v = it.min() + skip;
@@ -171,23 +171,23 @@ public:
 
   static BoolVar unused;
 
-  bool prune(const Assignment& a, IntTest& it, 
+  bool prune(const Assignment& a, IntTest& it,
 	     bool r, BoolVar& b = unused) {
     // Select variable to be pruned
-    int i = random(x.size());
+    int i = Test::randgen(x.size());
     while (x[i].assigned()) {
       i = (i+1) % x.size();
     }
     // Select mode for pruning
-    int m=random(3);
+    int m=Test::randgen(3);
     if ((m == 0) && (a[i] < x[i].max())) {
-      int v=a[i]+1+random(static_cast<unsigned int>(x[i].max()-a[i]));
+      int v=a[i]+1+Test::randgen(static_cast<unsigned int>(x[i].max()-a[i]));
       assert((v > a[i]) && (v <= x[i].max()));
       Log::prune(x[i], Log::mk_name("x", i), IRT_LE, v);
       rel(this, x[i], IRT_LE, v);
       Log::prune_result(x[i]);
     } else if ((m == 1) && (a[i] > x[i].min())) {
-      int v=x[i].min()+random(static_cast<unsigned int>(a[i]-x[i].min()));
+      int v=x[i].min()+Test::randgen(static_cast<unsigned int>(a[i]-x[i].min()));
       assert((v < a[i]) && (v >= x[i].min()));
       Log::prune(x[i], Log::mk_name("x", i), IRT_GR, v);
       rel(this, x[i], IRT_GR, v);
@@ -195,7 +195,7 @@ public:
     } else  {
       int v;
       Int::ViewRanges<Int::IntView> it(x[i]);
-      unsigned int skip = random(x[i].size()-1);
+      unsigned int skip = Test::randgen(x[i].size()-1);
       while (true) {
 	if (it.width() > skip) {
 	  v = it.min() + skip;
@@ -217,9 +217,9 @@ public:
       rel(this, x[i], IRT_NQ, v);
       Log::prune_result(x[i]);
     }
-    if (random(opt.fixprob) == 0) {		
+    if (Test::randgen(opt.fixprob) == 0) {		
       Log::fixpoint();
-      if (status() == SS_FAILED) 
+      if (status() == SS_FAILED)
 	return true;
       IntTestSpace* c = static_cast<IntTestSpace*>(clone());
       Log::print(c->x, "x");
@@ -265,20 +265,20 @@ public:
       }
       delete c;
     }						
-    if (random(opt.flushprob) == 0) {		
+    if (Test::randgen(opt.flushprob) == 0) {		
       flush();					
       Log::flush();				
     }		
     return true;
   }
-  
+
 };
 
 BoolVar IntTestSpace::unused;
 
 
 
-Assignment* 
+Assignment*
 IntTest::make_assignment() {
   return new Assignment(arity, dom);
 }
@@ -290,7 +290,7 @@ if (!(T)) { 					\
   goto failed; 					\
 }
 
-bool 
+bool
 IntTest::run(const Options& opt) {
   const char* test    = "NONE";
   const char* problem = "NONE";
@@ -311,7 +311,7 @@ IntTest::run(const Options& opt) {
       if (is_sol) {
 	IntTestSpace* s = e_s.next();
 	CHECK(s != NULL,    "Solutions exhausted");
-	CHECK(!s->actors(), "No subsumtion");
+	CHECK(s->propagators()==0, "No subsumtion");
 	for (int i=a.size(); i--; ) {
 	  CHECK(s->x[i].assigned(), "Unassigned variable");
 	  CHECK(a[i] == s->x[i].val(), "Wrong value in solution");
@@ -326,7 +326,7 @@ IntTest::run(const Options& opt) {
       post(s,s->x); s->assign(a);
       if (is_sol) {
 	CHECK(!s->is_failed(), "Failed on solution");
-	CHECK(!s->actors(), "No subsumtion");
+	CHECK(s->propagators()==0, "No subsumtion");
       } else {
 	CHECK(s->is_failed(), "Solved on non-solution");
       }
@@ -339,7 +339,7 @@ IntTest::run(const Options& opt) {
       s->assign(a); post(s,s->x);
       if (is_sol) {
 	CHECK(!s->is_failed(), "Failed on solution");
-	CHECK(!s->actors(), "No subsumtion");
+	CHECK(s->propagators()==0, "No subsumtion");
       } else {
 	CHECK(s->is_failed(), "Solved on non-solution");
       }
@@ -357,9 +357,9 @@ IntTest::run(const Options& opt) {
       } else {
 	rel(s, b, IRT_EQ, 0);
       }
-      s->assign(a); 
+      s->assign(a);
       CHECK(!s->is_failed(), "Failed");
-      CHECK(!s->actors(), "No subsumtion");
+      CHECK(s->propagators()==0, "No subsumtion");
       delete s;
     }
     if (reified) {
@@ -374,20 +374,20 @@ IntTest::run(const Options& opt) {
 	rel(s, b, IRT_EQ, 0);
       }
       post(s,s->x,b);
-      s->assign(a); 
+      s->assign(a);
       CHECK(!s->is_failed(), "Failed");
-      CHECK(!s->actors(), "No subsumtion");
+      CHECK(s->propagators()==0, "No subsumtion");
       delete s;
     }
     if (reified) {
       test = "Assignment reified (before posting)";
       Log::reset();
       IntTestSpace* s = new IntTestSpace(arity,dom,opt);
-      BoolVar b(s,0,1); 
+      BoolVar b(s,0,1);
       Log::initial(b, "b");
       s->assign(a); post(s,s->x,b);
       CHECK(!s->is_failed(), "Failed");
-      CHECK(!s->actors(), "No subsumtion");
+      CHECK(s->propagators()==0, "No subsumtion");
       CHECK(b.assigned(), "Control variable unassigned");
       if (is_sol) {
 	CHECK(b.val()==1, "Zero on solution");
@@ -404,7 +404,7 @@ IntTest::run(const Options& opt) {
       Log::initial(b, "b");
       post(s,s->x,b); s->assign(a);
       CHECK(!s->is_failed(), "Failed");
-      CHECK(!s->actors(), "No subsumtion");
+      CHECK(s->propagators()==0, "No subsumtion");
       CHECK(b.assigned(), "Control variable unassigned");
       if (is_sol) {
 	CHECK(b.val()==1, "Zero on solution");
@@ -427,7 +427,7 @@ IntTest::run(const Options& opt) {
       s->assign(a);
       if (is_sol) {
 	CHECK(!s->is_failed(), "Failed on solution");
-	CHECK(!s->actors(), "No subsumtion");
+	CHECK(s->propagators()==0, "No subsumtion");
       } else {
 	CHECK(s->is_failed(), "Solved on non-solution");
       }
@@ -447,7 +447,7 @@ IntTest::run(const Options& opt) {
 	  goto failed;
 	}
       CHECK(!s->is_failed(), "Failed");
-      CHECK(!s->actors(), "No subsumtion");
+      CHECK(s->propagators()==0, "No subsumtion");
       CHECK(b.assigned(), "Control variable unassigned");
       if (is_sol) {
 	CHECK(b.val()==1, "Zero on solution");
@@ -475,7 +475,7 @@ IntTest::run(const Options& opt) {
       s->prune();
     }
     CHECK(!s->is_failed(), "Failed");
-    CHECK(!s->actors(), "No subsumtion");
+    CHECK(s->propagators()==0, "No subsumtion");
     delete s;
     has_assignment = true;
   }
