@@ -6,8 +6,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2006-03-30 14:25:12 +0200 (Thu, 30 Mar 2006) $ by $Author: zayenz $
- *     $Revision: 3132 $
+ *     $Date: 2006-08-04 16:07:12 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3518 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -27,15 +27,15 @@
 
 namespace {
   const int s1r[7] = {
-    Limits::Int::int_min, Limits::Int::int_min+1, 
+    Limits::Int::int_min, Limits::Int::int_min+1,
     -1,0,1,
     Limits::Int::int_max-1, Limits::Int::int_max
-  }; 
+  };
   const int s2r[9] = {
     static_cast<int>(-sqrt(static_cast<double>(-Limits::Int::int_min))),
     -4,-2,-1,0,1,2,4,
     static_cast<int>(sqrt(static_cast<double>(Limits::Int::int_max)))
-  }; 
+  };
   IntSet s1(s1r,7);
   IntSet s2(s2r,9);
   IntSet s3(-8,8);
@@ -44,7 +44,7 @@ namespace {
 
 class Mult : public IntTest {
 public:
-  Mult(const char* t, const IntSet& is) 
+  Mult(const char* t, const IntSet& is)
     : IntTest(t,3,is) {}
   virtual bool solution(const Assignment& x) const {
     double d0 = static_cast<double>(x[0]);
@@ -66,7 +66,7 @@ namespace {
 
 class Square : public IntTest {
 public:
-  Square(const char* t, const IntSet& is) 
+  Square(const char* t, const IntSet& is)
     : IntTest(t,2,is) {}
   virtual bool solution(const Assignment& x) const {
     double d0 = static_cast<double>(x[0]);
@@ -85,7 +85,7 @@ namespace {
 
 class Abs : public IntTest {
 public:
-  Abs(const char* t, IntConLevel icl, const IntSet& is) 
+  Abs(const char* t, IntConLevel icl, const IntSet& is)
     : IntTest(t,2,is,false,icl) {}
   virtual bool solution(const Assignment& x) const {
     double d0 = static_cast<double>(x[0]);
@@ -109,7 +109,7 @@ namespace {
 
 class Min : public IntTest {
 public:
-  Min(const char* t, const IntSet& is) 
+  Min(const char* t, const IntSet& is)
     : IntTest(t,3,is) {}
   virtual bool solution(const Assignment& x) const {
     return std::min(x[0],x[1]) == x[2];
@@ -124,9 +124,26 @@ namespace {
   Min _minmin("Arithmetic::Min::Bin::C",s3);
 }
 
+class MinShared : public IntTest {
+public:
+  MinShared(const char* t, const IntSet& is)
+    : IntTest(t,2,is) {}
+  virtual bool solution(const Assignment& x) const {
+    return std::min(x[0],x[1]) == x[0];
+  }
+  virtual void post(Space* home, IntVarArray& x) {
+    min(home, x[0], x[1], x[0]);
+  }
+};
+namespace {
+  MinShared _minsmax("Arithmetic::Min::Bin::Shared::A",s1);
+  MinShared _minsmed("Arithmetic::Min::Bin::Shared::B",s2);
+  MinShared _minsmin("Arithmetic::Min::Bin::Shared::C",s3);
+}
+
 class Max : public IntTest {
 public:
-  Max(const char* t, const IntSet& is) 
+  Max(const char* t, const IntSet& is)
     : IntTest(t,3,is) {}
   virtual bool solution(const Assignment& x) const {
     return std::max(x[0],x[1]) == x[2];
@@ -141,9 +158,26 @@ namespace {
   Max _maxmin("Arithmetic::Max::Bin::C",s3);
 }
 
+class MaxShared : public IntTest {
+public:
+  MaxShared(const char* t, const IntSet& is)
+    : IntTest(t,2,is) {}
+  virtual bool solution(const Assignment& x) const {
+    return std::max(x[0],x[1]) == x[0];
+  }
+  virtual void post(Space* home, IntVarArray& x) {
+    max(home, x[0], x[1], x[0]);
+  }
+};
+namespace {
+  MaxShared _maxsmax("Arithmetic::Max::Bin::Shared::A",s1);
+  MaxShared _maxsmed("Arithmetic::Max::Bin::Shared::B",s2);
+  MaxShared _maxsmin("Arithmetic::Max::Bin::Shared::C",s3);
+}
+
 class MinNary : public IntTest {
 public:
-  MinNary(const char* t, const IntSet& is) 
+  MinNary(const char* t, const IntSet& is)
     : IntTest(t,4,is) {}
   virtual bool solution(const Assignment& x) const {
     return std::min(std::min(x[0],x[1]),
@@ -162,9 +196,30 @@ namespace {
   MinNary _minnary("Arithmetic::Min::Nary",s4);
 }
 
+class MinNaryShared : public IntTest {
+public:
+  MinNaryShared(const char* t, const IntSet& is)
+    : IntTest(t,3,is) {}
+  virtual bool solution(const Assignment& x) const {
+    return std::min(std::min(x[0],x[1]),
+		    x[2]) == x[1];
+  }
+  virtual void post(Space* home, IntVarArray& x) {
+    Log::log("min(home, x[0:2], x[1])",
+	     "\tIntVarArgs m(3); m[0]=x[0]; m[1]=x[1]; m[2]=x[2];\n"
+	     "\tmin(this, m, x[1]);");
+    IntVarArgs m(3);
+    m[0]=x[0]; m[1]=x[1]; m[2]=x[2];
+    min(home, m, x[1]);
+  }
+};
+namespace {
+  MinNaryShared _minsnary("Arithmetic::Min::Nary::Shared",s4);
+}
+
 class MaxNary : public IntTest {
 public:
-  MaxNary(const char* t, const IntSet& is) 
+  MaxNary(const char* t, const IntSet& is)
     : IntTest(t,4,is) {}
   virtual bool solution(const Assignment& x) const {
     return std::max(std::max(x[0],x[1]),
@@ -183,4 +238,25 @@ namespace {
   MaxNary _maxnary("Arithmetic::Max::Nary",s4);
 }
 
+class MaxNaryShared : public IntTest {
+public:
+  MaxNaryShared(const char* t, const IntSet& is)
+    : IntTest(t,3,is) {}
+  virtual bool solution(const Assignment& x) const {
+    return std::max(std::max(x[0],x[1]),
+		    x[2]) == x[1];
+  }
+  virtual void post(Space* home, IntVarArray& x) {
+    Log::log("max(home, x[0:2], x[1])",
+	     "\tIntVarArgs m(3); m[0]=x[0]; m[1]=x[1]; m[2]=x[2];\n"
+	     "\tmax(this, m, x[1]);");
+    IntVarArgs m(3);
+    m[0]=x[0]; m[1]=x[1]; m[2]=x[2];
+    max(home, m, x[1]);
+  }
+};
+namespace {
+  MaxNaryShared _maxsnary("Arithmetic::Max::Nary::Shared",s4);
+}
+
 // STATISTICS: test-int
