@@ -6,8 +6,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2005-11-02 16:07:10 +0100 (Wed, 02 Nov 2005) $ by $Author: schulte $
- *     $Revision: 2473 $
+ *     $Date: 2006-08-04 16:07:12 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3518 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -258,18 +258,39 @@ public:
 };
 MmBoolE _mmboole;
 
+class MmBoolF : public IntTest {
+public:
+  MmBoolF(void)
+    : IntTest("MiniModel::Bool::F",4,b,false) {}
+  virtual bool solution(const Assignment& x) const {
+    for (int i=0; i<x.size(); i++)
+      if ((x[i] <0) || (x[i]>1))
+	return false;
+    return ((x[0]==1) || (x[1]==1)) || ((x[2]==1) || (x[3]==1));
+  }
+  virtual void post(Space* home, IntVarArray& x) {
+    BoolVarArgs b(4);
+    for (int i=x.size(); i--; ) {
+      Gecode::dom(home, x[i], 0, 1);
+      BoolVar bx(x[i]); b[i]=bx;
+    }
+    Gecode::post(home, tt(b[0] || b[1] || b[2] || b[3]));
+  }
+};
+MmBoolF _mmboolf;
+
 
 namespace {
   const int s1r[7] = {
-    Limits::Int::int_min, Limits::Int::int_min+1, 
+    Limits::Int::int_min, Limits::Int::int_min+1,
     -1,0,1,
     Limits::Int::int_max-1, Limits::Int::int_max
-  }; 
+  };
   const int s2r[9] = {
     static_cast<int>(-sqrt(static_cast<double>(-Limits::Int::int_min))),
     -4,-2,-1,0,1,2,4,
     static_cast<int>(sqrt(static_cast<double>(Limits::Int::int_max)))
-  }; 
+  };
   IntSet s1(s1r,7);
   IntSet s2(s2r,9);
   IntSet s3(-8,8);
@@ -278,7 +299,7 @@ namespace {
 
 class Mult : public IntTest {
 public:
-  Mult(const char* t, const IntSet& is) 
+  Mult(const char* t, const IntSet& is)
     : IntTest(t,3,is) {}
   virtual bool solution(const Assignment& x) const {
     double d0 = static_cast<double>(x[0]);
@@ -301,7 +322,7 @@ namespace {
 
 class Square : public IntTest {
 public:
-  Square(const char* t, const IntSet& is) 
+  Square(const char* t, const IntSet& is)
     : IntTest(t,2,is) {}
   virtual bool solution(const Assignment& x) const {
     double d0 = static_cast<double>(x[0]);
@@ -321,7 +342,7 @@ namespace {
 
 class Abs : public IntTest {
 public:
-  Abs(const char* t, IntConLevel icl, const IntSet& is) 
+  Abs(const char* t, IntConLevel icl, const IntSet& is)
     : IntTest(t,2,is,false,icl) {}
   virtual bool solution(const Assignment& x) const {
     double d0 = static_cast<double>(x[0]);
@@ -346,7 +367,7 @@ namespace {
 
 class Min : public IntTest {
 public:
-  Min(const char* t, const IntSet& is) 
+  Min(const char* t, const IntSet& is)
     : IntTest(t,3,is) {}
   virtual bool solution(const Assignment& x) const {
     return std::min(x[0],x[1]) == x[2];
@@ -364,7 +385,7 @@ namespace {
 
 class Max : public IntTest {
 public:
-  Max(const char* t, const IntSet& is) 
+  Max(const char* t, const IntSet& is)
     : IntTest(t,3,is) {}
   virtual bool solution(const Assignment& x) const {
     return std::max(x[0],x[1]) == x[2];
@@ -382,7 +403,7 @@ namespace {
 
 class MinNary : public IntTest {
 public:
-  MinNary(const char* t, const IntSet& is) 
+  MinNary(const char* t, const IntSet& is)
     : IntTest(t,4,is) {}
   virtual bool solution(const Assignment& x) const {
     return std::min(std::min(x[0],x[1]),
@@ -404,7 +425,7 @@ namespace {
 
 class MaxNary : public IntTest {
 public:
-  MaxNary(const char* t, const IntSet& is) 
+  MaxNary(const char* t, const IntSet& is)
     : IntTest(t,4,is) {}
   virtual bool solution(const Assignment& x) const {
     return std::max(std::max(x[0],x[1]),
