@@ -10,8 +10,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2005-11-01 16:01:21 +0100 (Tue, 01 Nov 2005) $ by $Author: zayenz $
- *     $Revision: 2465 $
+ *     $Date: 2006-08-04 16:07:12 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3518 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -37,7 +37,7 @@ CountableSet::CountableSet(const IntSet& d0) : d(d0), //curd(IntSet::empty),
 }
 
 void CountableSet::operator++(void) {
-  cur++; 
+  cur++;
 }
 
 void CountableSet::init(const IntSet& d0) {
@@ -58,8 +58,8 @@ SetAssignment::SetAssignment(int n0, const IntSet& d0, int _withInt)
   for (int i=n; i--; )
     dsv[i].init(lub);
 }
- 
-void 
+
+void
 SetAssignment::reset(void) {
   done = false;
   for (int i=n; i--; )
@@ -67,7 +67,7 @@ SetAssignment::reset(void) {
   ir.reset();
 }
 
-void 
+void
 SetAssignment::operator++(void) {
   int i = n-1;
   while (true) {
@@ -109,12 +109,11 @@ operator<<(std::ostream& os, const SetAssignment& a) {
 
 #define FORCE_FIXFLUSH				\
 do {						\
-  if (random(opt.fixprob) == 0) {		\
-    unsigned int alt;				\
+  if (Test::randgen(opt.fixprob) == 0) {	\
     Log::fixpoint();				\
-    if (status(alt) == SS_FAILED) return;	\
+    if (status() == SS_FAILED) return;		\
   }						\
-  if (random(opt.flushprob) == 0) {		\
+  if (Test::randgen(opt.flushprob) == 0) {	\
     flush();					\
     Log::flush();				\
   }						\
@@ -128,12 +127,12 @@ private:
   const Options opt;
   int withInt;
 public:
-  SetTestSpace(int n, IntSet& d, int _withInt, const Options& o) 
+  SetTestSpace(int n, IntSet& d, int _withInt, const Options& o)
     : x(this, n, IntSet::empty, d), y(this, _withInt, d),
       opt(o), withInt(_withInt) {
     Log::initial(x, "x");
   }
-  SetTestSpace(bool share, SetTestSpace& s) : Space(share,s), opt(s.opt), 
+  SetTestSpace(bool share, SetTestSpace& s) : Space(share,s), opt(s.opt),
 					      withInt(s.withInt) {
     x.update(this, share, s.x);
     y.update(this, share, s.y);
@@ -142,8 +141,7 @@ public:
     return new SetTestSpace(share,*this);
   }
   bool failed(void) {
-    unsigned int alt;
-    return status(alt) == SS_FAILED;
+    return status() == SS_FAILED;
   }
   void assign(const SetAssignment& a) {
     for (int i=a.size(); i--; ) {
@@ -178,7 +176,7 @@ public:
     for (int j=0; j<v; j++, ++diffV);
     Log::prune(x, Log::mk_name("x", i), SRT_DISJ, diffV.val());
     dom(this, x, SRT_DISJ, diffV.val());
-    Log::prune_result(x);      
+    Log::prune_result(x);
   }
 
   void addToGlb(int v, SetVar& x, int i, const SetAssignment& a) {
@@ -191,13 +189,12 @@ public:
     for (int j=0; j<v; j++, ++interV);
     Log::prune(x, Log::mk_name("x", i), SRT_SUP, interV.val());
     dom(this, x, SRT_SUP, interV.val());
-    Log::prune_result(x);      
+    Log::prune_result(x);
   }
 
   bool fixprob(SetTest& st, bool r, BoolVar& b) {
-    unsigned int alt;				
     Log::fixpoint();				
-    if (status(alt) == SS_FAILED) 
+    if (status() == SS_FAILED)
       return true;
     SetTestSpace* c = static_cast<SetTestSpace*>(clone());
     Log::print(c->x, "x");
@@ -205,7 +202,7 @@ public:
     if (!r) {
       st.post(c,c->x,c->y);
       Log::fixpoint();
-      if (c->status(alt) == SS_FAILED) {
+      if (c->status() == SS_FAILED) {
 	Log::print(c->x, "x");
 	if (c->y.size() > 0) Log::print(c->y, "y");
 	delete c;
@@ -228,7 +225,7 @@ public:
       Log::initial(cb, "cb");
       st.post(c,c->x,c->y,cb);
       Log::fixpoint();
-      if (c->status(alt) == SS_FAILED) {
+      if (c->status() == SS_FAILED) {
 	Log::print(c->x, "x");
 	if (c->y.size() > 0) Log::print(c->y, "y");
 	Log::print(cb, "cb");
@@ -278,11 +275,11 @@ public:
     // Select variable to be pruned
     int i;
     if (intsAssigned) {
-      i = random(x.size());
+      i = Test::randgen(x.size());
     } else if (setsAssigned) {
-      i = random(y.size());
+      i = Test::randgen(y.size());
     } else {
-      i = random(x.size()+y.size());
+      i = Test::randgen(x.size()+y.size());
     }
 
     if (setsAssigned || i>=x.size()) {
@@ -295,17 +292,17 @@ public:
 
 
       // Select mode for pruning
-      int m=random(3);
+      int m=Test::randgen(3);
       if ((m == 0) && (a.ints()[i] < y[i].max())) {
 	int v=a.ints()[i]+1+
-	  random(static_cast<unsigned int>(y[i].max()-a.ints()[i]));
+	  Test::randgen(static_cast<unsigned int>(y[i].max()-a.ints()[i]));
 	assert((v > a.ints()[i]) && (v <= y[i].max()));
 	Log::prune(y[i], Log::mk_name("y", i), IRT_LE, v);
 	rel(this, y[i], IRT_LE, v);
 	Log::prune_result(y[i]);
       } else if ((m == 1) && (a.ints()[i] > y[i].min())) {
 	int v=y[i].min()+
-	  random(static_cast<unsigned int>(a.ints()[i]-y[i].min()));
+	  Test::randgen(static_cast<unsigned int>(a.ints()[i]-y[i].min()));
 	assert((v < a.ints()[i]) && (v >= y[i].min()));
 	Log::prune(y[i], Log::mk_name("y", i), IRT_GR, v);
 	rel(this, y[i], IRT_GR, v);
@@ -313,7 +310,7 @@ public:
       } else  {
 	int v;
 	Int::ViewRanges<Int::IntView> it(y[i]);
-	unsigned int skip = random(y[i].size()-1);
+	unsigned int skip = Test::randgen(y[i].size()-1);
 	while (true) {
 	  if (it.width() > skip) {
 	    v = it.min() + skip;
@@ -335,9 +332,9 @@ public:
 	rel(this, y[i], IRT_NQ, v);
 	Log::prune_result(y[i]);
       }
-      if (random(opt.fixprob) == 0 && !fixprob(st, r, b))
+      if (Test::randgen(opt.fixprob) == 0 && !fixprob(st, r, b))
 	return false;
-      if (random(opt.flushprob) == 0) {		
+      if (Test::randgen(opt.flushprob) == 0) {		
 	flush();					
 	Log::flush();				
       }		
@@ -359,22 +356,24 @@ public:
     unsigned int aisize = Iter::Ranges::size(aisizer);
 
     // Select mode for pruning
-    int m=random(5);
+    int m=Test::randgen(5);
     if (m==0 && inter()) {
-      int v = random(Iter::Ranges::size(inter));
+      int v = Test::randgen(Iter::Ranges::size(inter));
       addToGlb(v, x[i], i, a);
     } else if (m==1 && diff()) {
-      int v = random(Iter::Ranges::size(diff));
+      int v = Test::randgen(Iter::Ranges::size(diff));
       removeFromLub(v, x[i], i, a);
     } else if (m==2 && x[i].cardMin() < aisize) {
-      unsigned int newc = x[i].cardMin() + 1 + random(aisize - x[i].cardMin());
+      unsigned int newc = x[i].cardMin() + 1 +
+	Test::randgen(aisize - x[i].cardMin());
       assert( newc > x[i].cardMin() );
       assert( newc <= aisize );
       Log::prune(x[i], Log::mk_name("x", i), newc, Limits::Set::card_max);
       cardinality(this, x[i], newc, Limits::Set::card_max);
       Log::prune_result(x[i]);
     } else if (m==3 && x[i].cardMax() > aisize) {
-      unsigned int newc = x[i].cardMax() - 1 - random(x[i].cardMax() - aisize);
+      unsigned int newc = x[i].cardMax() - 1 -
+	Test::randgen(x[i].cardMax() - aisize);
       assert( newc < x[i].cardMax() );
       assert( newc >= aisize );
       Log::prune(x[i], Log::mk_name("x", i), 0, newc);
@@ -382,23 +381,23 @@ public:
       Log::prune_result(x[i]);
     } else {
       if (inter()) {
-	int v = random(Iter::Ranges::size(inter));
+	int v = Test::randgen(Iter::Ranges::size(inter));
 	addToGlb(v, x[i], i, a);
       } else {
-	int v = random(Iter::Ranges::size(diff));
+	int v = Test::randgen(Iter::Ranges::size(diff));
 	removeFromLub(v, x[i], i, a);
       }
     }
-    if (random(opt.fixprob) == 0 && !fixprob(st, r, b))
+    if (Test::randgen(opt.fixprob) == 0 && !fixprob(st, r, b))
       return false;
-    if (random(opt.flushprob) == 0) {		
+    if (Test::randgen(opt.flushprob) == 0) {		
       flush();					
       Log::flush();				
     }		
 
     return true;
   }
-  
+
 };
 
 BoolVar SetTestSpace::unused;
@@ -416,7 +415,7 @@ SetTest::make_assignment(void) {
   return new SetAssignment(arity,lub,withInt);
 }
 
-bool 
+bool
 SetTest::run(const Options& opt) {
   const char* test    = "NONE";
   const char* problem = "NONE";
@@ -432,7 +431,7 @@ SetTest::run(const Options& opt) {
       post(s,s->x,s->y); s->assign(a);
       if (is_sol) {
 	CHECK(!s->failed(), "Failed on solution");
-	CHECK(!s->actors(), "No subsumtion");
+	CHECK(s->propagators()==0, "No subsumtion");
       } else {
 	CHECK(s->failed(), "Solved on non-solution");
       }
@@ -445,7 +444,7 @@ SetTest::run(const Options& opt) {
       s->assign(a); post(s,s->x,s->y);
       if (is_sol) {
 	CHECK(!s->failed(), "Failed on solution");
-	CHECK(!s->actors(), "No subsumtion");
+	CHECK(s->propagators()==0, "No subsumtion");
       } else {
 	CHECK(s->failed(), "Solved on non-solution");
       }
@@ -455,10 +454,10 @@ SetTest::run(const Options& opt) {
       test = "Assignment reified (before posting)";
       Log::reset();
       SetTestSpace* s = new SetTestSpace(arity,lub,withInt,opt);
-      BoolVar b(s,0,1); 
+      BoolVar b(s,0,1);
       s->assign(a); post(s,s->x,s->y,b);
       CHECK(!s->failed(), "Failed");
-      CHECK(!s->actors(), "No subsumtion");
+      CHECK(s->propagators()==0, "No subsumtion");
       CHECK(b.assigned(), "Control variable unassigned");
       if (is_sol) {
 	CHECK(b.val()==1, "Zero on solution");
@@ -474,7 +473,7 @@ SetTest::run(const Options& opt) {
       BoolVar b(s,0,1);
       post(s,s->x,s->y,b); s->assign(a);
       CHECK(!s->failed(), "Failed");
-      CHECK(!s->actors(), "No subsumtion");
+      CHECK(s->propagators()==0, "No subsumtion");
       CHECK(b.assigned(), "Control variable unassigned");
       if (is_sol) {
 	CHECK(b.val()==1, "Zero on solution");
@@ -497,7 +496,7 @@ SetTest::run(const Options& opt) {
       s->assign(a);
       if (is_sol) {
 	CHECK(!s->failed(), "Failed on solution");
-	CHECK(!s->actors(), "No subsumtion");
+	CHECK(s->propagators()==0, "No subsumtion");
       } else {
 	CHECK(s->failed(), "Solved on non-solution");
       }
@@ -516,7 +515,7 @@ SetTest::run(const Options& opt) {
  	  goto failed;
  	}
       CHECK(!s->failed(), "Failed");
-      CHECK(!s->actors(), "No subsumtion");
+      CHECK(s->propagators()==0, "No subsumtion");
       CHECK(b.assigned(), "Control variable unassigned");
       if (is_sol) {
 	CHECK(b.val()==1, "Zero on solution");
