@@ -8,8 +8,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2005-11-07 17:15:40 +0100 (mån, 07 nov 2005) $ by $Author: zayenz $
- *     $Revision: 2519 $
+ *     $Date: 2006-08-04 16:07:12 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3518 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -27,11 +27,11 @@
 
 #include "gecode/search.hh"
 
-StressTestSpace::StressTestSpace(int n, IntSet dom, const Options& o) 
+StressTestSpace::StressTestSpace(int n, IntSet dom, const Options& o)
   : x(this, n, dom), opt(o) {
   Log::initial(x, "x");
 }
-StressTestSpace::StressTestSpace(bool share, StressTestSpace& s) 
+StressTestSpace::StressTestSpace(bool share, StressTestSpace& s)
   : Space(share,s), opt(s.opt) {
   x.update(this, share, s.x);
 }
@@ -39,9 +39,8 @@ Space* StressTestSpace::copy(bool share) {
   return new StressTestSpace(share,*this);
 }
 bool StressTestSpace::is_failed(void) {
-  unsigned int alt;
   Log::fixpoint();
-  return status(alt) == SS_FAILED;
+  return status() == SS_FAILED;
 }
 
 StressTestSpace *
@@ -54,7 +53,7 @@ problem = (M);    \
 delete e;         \
 goto failed;
 
-bool 
+bool
 StressTest::run(const Options& opt) {
   const char* problem = "NONE";
   while (param()) {
