@@ -8,8 +8,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2006-06-06 23:39:42 +0200 (Tue, 06 Jun 2006) $ by $Author: tack $
- *     $Revision: 3270 $
+ *     $Date: 2006-08-04 16:07:12 +0200 (Fri, 04 Aug 2006) $ by $Author: schulte $
+ *     $Revision: 3518 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,25 +43,9 @@ using std::pair;
 
 vector<pair<bool, const char*> > testpat;
 
-#include "test/random.hh"
-
 Test* Test::all = NULL;
+Support::RandomGenerator Test::randgen = Support::RandomGenerator();
 
-/// Return number between 0..m-1
-int random(int m) {
-  double d = ((double) test_rand()) / TEST_RAND_MAX;
-  int n = static_cast<int>(m * d);
-  return (n < m) ? n : (m-1);
-}
-
-/// Return number between 0..m-1
-unsigned int random(unsigned int m) {
-  if (m < 2)
-    return 0;
-  double d = ((double) test_rand()) / TEST_RAND_MAX;
-  unsigned int n = static_cast<unsigned int>(m * d);
-  return (n < m) ? n : (m-1);
-}
 
 namespace {
 
@@ -85,7 +69,7 @@ main(int argc, char** argv) {
 
   Options o;
   o.parse(argc, argv);
-  test_seed(o.seed);
+  Test::randgen.seed(o.seed);
   Log::logging(o.log);
 
   for (Test* t = Test::tests(); t != NULL; t = t->next()) {
@@ -109,7 +93,7 @@ main(int argc, char** argv) {
       std::cout << name << ": ";
       std::cout.flush();
       for (int i = o.iter; i--; ) {
-	o.seed = test_seed();
+	o.seed = Test::randgen.seed();
 	if (t->run(o)) {
 	  std::cout << "+";
 	  std::cout.flush();
@@ -121,11 +105,11 @@ main(int argc, char** argv) {
       }
     std::cout << std::endl;
     } catch (Gecode::Exception e) {
-      std::cout << "Exception in \"Gecode::" << e.location() 
-		<< "\": " << e.info() << "." << std::endl
+      std::cout << "Exception in \"Gecode::" << e.what()
+		<< "." << std::endl
 		<< "Stopping..." << std::endl;
 	  report_error(o, name);
-	  if(o.stop_on_error) return 1;      
+	  if(o.stop_on_error) return 1;
     }
   next:;
   }
@@ -135,7 +119,7 @@ main(int argc, char** argv) {
 void
 Options::parse(int argc, char** argv) {
   using namespace std;
-  static const char* bool2str[] = 
+  static const char* bool2str[] =
     { "false", "true" };
   int i = 1;
   const char* e = NULL;
@@ -143,32 +127,32 @@ Options::parse(int argc, char** argv) {
     if (!strcmp(argv[i],"-help") || !strcmp(argv[i],"--help")) {
       std::cerr << "Options for testing:" << std::endl
 		<< "\t-seed (unsigned int|\"time\") default: " <<seed<< std::endl
-		<< "\t\tthe seed for the random numbers (an integer)," 
-		<< std::endl 
+		<< "\t\tthe seed for the random numbers (an integer),"
+		<< std::endl
 		<< "\t\tor the word time for a random seed based on the "
 		<< "current time" << std::endl
 		<< "\t-fixprob (unsigned int) default: " <<fixprob<< std::endl
-		<< "\t\t1/fixprob is the probability of fixpoint recalculations" 
+		<< "\t\t1/fixprob is the probability of fixpoint recalculations"
 		<< std::endl
 		<< "\t-flushprob (unsigned int) default: " <<flushprob<< std::endl
-		<< "\t\t1/flushprob is the probability of flushing the the caches" 
+		<< "\t\t1/flushprob is the probability of flushing the the caches"
 		<< std::endl
 		<< "\t-iter (unsigned int) default: " <<iter<< std::endl
 		<< "\t\tthe number of iterations" << std::endl
 		<< "\t-test (string) default: (none)" << std::endl
 		<< "\t\tsimple pattern for the tests to run" << std::endl
-		<< "\t\tprefixing the pattern by a - negates the pattern" 
+		<< "\t\tprefixing the pattern by a - negates the pattern"
 		<< std::endl
 		<< "\t\tmultiple pattern-options may be given" << std::endl
-		<< "\t-log (opt \"text\"|\"code\") default: off" 
+		<< "\t-log (opt \"text\"|\"code\") default: off"
 		<< std::endl
 		<< "\t\tif given, logging will be printed for failures"
 		<< std::endl
-		<< "\t\tthe optional argument determines the style of the log" 
+		<< "\t\tthe optional argument determines the style of the log"
 		<< std::endl
 		<< "\t\twith text as the default style"
 		<< std::endl
-		<< "\t-stop (boolean) default: " 
+		<< "\t-stop (boolean) default: "
 		<< bool2str[stop_on_error] << std::endl
 		<< "\t\tstop on first error or continue" << std::endl;
       exit(EXIT_SUCCESS);
@@ -212,7 +196,7 @@ Options::parse(int argc, char** argv) {
 	stop_on_error = true;
       } else if (argv[i][0] == 'f') {
 	stop_on_error = false;
-      }      
+      }
     } else {
       i++;
       goto error;
